/* Funnel3DPlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Thu Nov 21 10:01:28 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for funnel3d plot
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class Funnel3DPlotOptions extends FunnelPlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		edgeWidth, gradientForSides, groupZPadding
	}

	/**
	 * 3D columns only. Returns the width of the colored edges.
	 * <p>
	 * Default: 0
	 */
	public Number getEdgeWidth() {
		return getAttr(Attrs.edgeWidth, 0).asNumber();
	}

	/**
	 * 3D columns only. Sets the width of the colored edges.
	 */
	public void setEdgeWidth(Number edgeWidth) {
		setAttr(Attrs.edgeWidth, edgeWidth);
	}

	/**
	 * By default sides fill is set to a gradient through this option being set to true.
	 * Set to false to get solid color for the sides.
	 * <p>
	 * Default: true
	 */
	public boolean isGradientForSides() {
		return getAttr(Attrs.gradientForSides, true).asBoolean();
	}

	/**
	 * By default sides fill is set to a gradient through this option being set to true.
	 * Set to false to get solid color for the sides.
	 */
	public void setGradientForSides(boolean gradientForSides) {
		setAttr(Attrs.gradientForSides, gradientForSides);
	}

	/**
	 * Returns the spacing between columns on the Z Axis in a 3D chart.
	 * <p>
	 * Default: 1
	 */
	public Number getGroupZPadding() {
		return getAttr(Attrs.groupZPadding, 1).asNumber();
	}

	/**
	 * Sets the spacing between columns on the Z Axis in a 3D chart.
	 * <p>
	 * Default: 1
	 */
	public void setGroupZPadding(Number groupZPadding) {
		setAttr(Attrs.groupZPadding, groupZPadding);
	}
}
