/* NetworkGraphPlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Fri Nov 15 11:15:06 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for networkgraph plot.
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class NetworkGraphPlotOptions extends SeriesPlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		draggable, layoutAlgorithm, link
	}

	@Override
	protected DataLabels newDataLabels() {
		return new NetworkGraphDataLabels();
	}

	@Override
	public NetworkGraphDataLabels getDataLabels() {
		return (NetworkGraphDataLabels) super.getDataLabels();
	}

	/**
	 * Returns the flag to determine if nodes are draggable or not.
	 * <p>
	 * Default: true
	 */
	public boolean getDraggable() {
		return getAttr(Attrs.draggable, true).asBoolean();
	}

	/**
	 * Sets the flag to determine if nodes are draggable or not.
	 */
	public void setDraggable(boolean draggable) {
		setAttr(Attrs.draggable, draggable, true);
	}

	/**
	 * Returns the layoutAlgorithm options, if any. Otherwise, create a new one.
	 */
	public NetworkGraphLayoutAlgorithm getLayoutAlgorithm() {
		NetworkGraphLayoutAlgorithm layoutAlgorithm = (NetworkGraphLayoutAlgorithm) getAttr(Attrs.layoutAlgorithm);
		if (layoutAlgorithm == null) {
			layoutAlgorithm = new NetworkGraphLayoutAlgorithm();
			setLayoutAlgorithm(layoutAlgorithm);
		}
		return layoutAlgorithm;
	}

	/**
	 * Sets the layoutAlgorithm options.
	 */
	public void setLayoutAlgorithm(NetworkGraphLayoutAlgorithm layoutAlgorithm) {
		setAttr(Attrs.layoutAlgorithm, layoutAlgorithm);
	}

	/**
	 * Returns the link style options, if any. Otherwise, create a new one.
	 */
	public NetworkGraphLink getLink() {
		NetworkGraphLink link = (NetworkGraphLink) getAttr(Attrs.link);
		if (link == null) {
			link = new NetworkGraphLink();
			setLink(link);
		}
		return link;
	}

	/**
	 * Sets the link style options.
	 */
	public void setLink(NetworkGraphLink link) {
		setAttr(Attrs.link, link);
	}
}
