/* PlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Tue, Jan 14, 2014  9:43:00 PM, Created by RaymondChao

Copyright (C) 2014 Potix Corporation. All Rights Reserved.

 */
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.Optionable;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for all plots
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 * 
 * @author RaymondChao
 */
public class PlotOptions extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		area,
		arearange,
		areaspline,
		areasplinerange,
		bar,
		bellcurve,
		boxplot,
		bubble,
		bullet,
		column,
		columnpyramid,
		columnrange,
		cylinder,
		dependencywheel,
		errorbar,
		funnel,
		funnel3d,
		gauge,
		heatmap,
		histogram,
		item,
		line,
		networkgraph,
		organization,
		packedbubble,
		pareto,
		pie,
		polygon,
		pyramid,
		pyramid3d,
		sankey,
		scatter,
		scatter3d,
		series,
		solidgauge,
		spline,
		streamgraph,
		sunburst,
		tilemap,
		timeline,
		treemap,
		variablepie,
		variwide,
		vector,
		venn,
		waterfall,
		windbarb,
		wordcloud,
		xrange
	}

	/**
	 * Returns the area plot option
	 */
	public AreaPlotOptions getArea() {
		AreaPlotOptions areaPlotOptions = (AreaPlotOptions) getAttr(Attrs.area);
		if (areaPlotOptions == null) {
			areaPlotOptions = new AreaPlotOptions();
			setAttr(Attrs.area, areaPlotOptions);
		}
		return areaPlotOptions;
	}

	/**
	 * Returns the area range plot option
	 */
	public AreaRangePlotOptions getAreaRange() {
		AreaRangePlotOptions areaRangePlotOptions = (AreaRangePlotOptions) getAttr(Attrs.arearange);
		if (areaRangePlotOptions == null) {
			areaRangePlotOptions = new AreaRangePlotOptions();
			setAttr(Attrs.arearange, areaRangePlotOptions);
		}
		return areaRangePlotOptions;
	}
	
	/**
	 * Returns the areaspline plot option
	 */
	public AreaSplinePlotOptions getAreaSpline() {
		AreaSplinePlotOptions areaSplinePlotOptions = (AreaSplinePlotOptions) getAttr(Attrs.areaspline);
		if (areaSplinePlotOptions == null) {
			areaSplinePlotOptions = new AreaSplinePlotOptions();
			setAttr(Attrs.areaspline, areaSplinePlotOptions);
		}
		return areaSplinePlotOptions;
	}

	/**
	 * Returns the areaspline range plot option
	 */
	public AreaSplineRangePlotOptions getAreaSplineRange() {
		AreaSplineRangePlotOptions areaSplineRangePlotOptions = (AreaSplineRangePlotOptions) getAttr(Attrs.areasplinerange);
		if (areaSplineRangePlotOptions == null) {
			areaSplineRangePlotOptions = new AreaSplineRangePlotOptions();
			setAttr(Attrs.areasplinerange, areaSplineRangePlotOptions);
		}
		return areaSplineRangePlotOptions;
	}

	/**
	 * Returns the bar plot option
	 */
	public BarPlotOptions getBar() {
		BarPlotOptions barPlotOptions = (BarPlotOptions) getAttr(Attrs.bar);
		if (barPlotOptions == null) {
			barPlotOptions = new BarPlotOptions();
			setAttr(Attrs.bar, barPlotOptions);
		}
		return barPlotOptions;
	}

	/**
	 * Returns the bell curve plot option
	 * @since 7.2.1.0
	 */
	public BellCurvePlotOptions getBellCurve() {
		BellCurvePlotOptions plotOptions = (BellCurvePlotOptions) getAttr(Attrs.bellcurve);
		if (plotOptions == null) {
			plotOptions = new BellCurvePlotOptions();
			setAttr(Attrs.bellcurve, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the box plot option
	 */
	public BoxPlotOptions getBoxPlot() {
		BoxPlotOptions boxPlotOptions = (BoxPlotOptions) getAttr(Attrs.boxplot);
		if (boxPlotOptions == null) {
			boxPlotOptions = new BoxPlotOptions();
			setAttr(Attrs.boxplot, boxPlotOptions);
		}
		return boxPlotOptions;
	}

	/**
	 * Returns the bubble plot option
	 */
	public BubblePlotOptions getBubble() {
		BubblePlotOptions bubblePlotOptions = (BubblePlotOptions) getAttr(Attrs.bubble);
		if (bubblePlotOptions == null) {
			bubblePlotOptions = new BubblePlotOptions();
			setAttr(Attrs.bubble, bubblePlotOptions);
		}
		return bubblePlotOptions;
	}

	/**
	 * Returns the bullet plot option
	 * @since 7.2.1.0
	 */
	public BulletPlotOptions getBullet() {
		BulletPlotOptions plotOptions = (BulletPlotOptions) getAttr(Attrs.bullet);
		if (plotOptions == null) {
			plotOptions = new BulletPlotOptions();
			setAttr(Attrs.bullet, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the column plot option
	 */
	public ColumnPlotOptions getColumn() {
		ColumnPlotOptions columnPlotOptions = (ColumnPlotOptions) getAttr(Attrs.column);
		if (columnPlotOptions == null) {
			columnPlotOptions = new ColumnPlotOptions();
			setAttr(Attrs.column, columnPlotOptions);
		}
		return columnPlotOptions;
	}

	/**
	 * Returns the column pyramid plot option
	 * @since 7.2.1.0
	 */
	public ColumnPyramidPlotOptions getColumnPyramid() {
		ColumnPyramidPlotOptions plotOptions = (ColumnPyramidPlotOptions) getAttr(Attrs.columnpyramid);
		if (plotOptions == null) {
			plotOptions = new ColumnPyramidPlotOptions();
			setAttr(Attrs.columnpyramid, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the column range plot option
	 */
	public ColumnRangePlotOptions getColumnRange() {
		ColumnRangePlotOptions columnRangePlotOptions = (ColumnRangePlotOptions) getAttr(Attrs.columnrange);
		if (columnRangePlotOptions == null) {
			columnRangePlotOptions = new ColumnRangePlotOptions();
			setAttr(Attrs.columnrange, columnRangePlotOptions);
		}
		return columnRangePlotOptions;
	}

	/**
	 * Returns the cylinder plot option
	 * @since 7.2.1.0
	 */
	public CylinderPlotOptions getCylinder() {
		CylinderPlotOptions plotOptions = (CylinderPlotOptions) getAttr(Attrs.cylinder);
		if (plotOptions == null) {
			plotOptions = new CylinderPlotOptions();
			setAttr(Attrs.cylinder, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the dependency wheel plot option
	 * @since 7.2.1.0
	 */
	public DependencyWheelPlotOptions getDependencyWheel() {
		DependencyWheelPlotOptions plotOptions = (DependencyWheelPlotOptions) getAttr(Attrs.dependencywheel);
		if (plotOptions == null) {
			plotOptions = new DependencyWheelPlotOptions();
			setAttr(Attrs.dependencywheel, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the error bar plot option
	 */
	public ErrorBarPlotOptions getErrorBar() {
		ErrorBarPlotOptions errorBarPlotOptions = (ErrorBarPlotOptions) getAttr(Attrs.errorbar);
		if (errorBarPlotOptions == null) {
			errorBarPlotOptions = new ErrorBarPlotOptions();
			setAttr(Attrs.errorbar, errorBarPlotOptions);
		}
		return errorBarPlotOptions;
	}

	/**
	 * Returns the funnel plot option
	 */
	public FunnelPlotOptions getFunnel() {
		FunnelPlotOptions funnelPlotOptions = (FunnelPlotOptions) getAttr(Attrs.funnel);
		if (funnelPlotOptions == null) {
			funnelPlotOptions = new FunnelPlotOptions();
			setAttr(Attrs.funnel, funnelPlotOptions);
		}
		return funnelPlotOptions;
	}

	/**
	 * Returns the funnel 3d plot option
	 * @since 7.2.1.0
	 */
	public Funnel3DPlotOptions getFunnel3D() {
		Funnel3DPlotOptions plotOptions = (Funnel3DPlotOptions) getAttr(Attrs.funnel3d);
		if (plotOptions == null) {
			plotOptions = new Funnel3DPlotOptions();
			setAttr(Attrs.funnel3d, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the gauge plot option
	 */
	public GaugePlotOptions getGauge() {
		GaugePlotOptions gaugePlotOptions = (GaugePlotOptions) getAttr(Attrs.gauge);
		if (gaugePlotOptions == null) {
			gaugePlotOptions = new GaugePlotOptions();
			setAttr(Attrs.gauge, gaugePlotOptions);
		}
		return gaugePlotOptions;
	}

	/**
	 * Returns the heatmap plot option
	 */
	public HeatmapPlotOptions getHeat() {
		HeatmapPlotOptions heatPlotOptions = (HeatmapPlotOptions) getAttr(Attrs.heatmap);
		if (heatPlotOptions == null) {
			heatPlotOptions = new HeatmapPlotOptions();
			setAttr(Attrs.heatmap, heatPlotOptions);
		}
		return heatPlotOptions;
	}

	/**
	 * Returns the histogram plot option
	 * @since 7.2.1.0
	 */
	public HistogramPlotOptions getHistogram() {
		HistogramPlotOptions plotOptions = (HistogramPlotOptions) getAttr(Attrs.histogram);
		if (plotOptions == null) {
			plotOptions = new HistogramPlotOptions();
			setAttr(Attrs.histogram, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the item plot option
	 * @since 7.2.1.0
	 */
	public ItemPlotOptions getItem() {
		ItemPlotOptions plotOptions = (ItemPlotOptions) getAttr(Attrs.item);
		if (plotOptions == null) {
			plotOptions = new ItemPlotOptions();
			setAttr(Attrs.item, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the line plot option
	 */
	public LinePlotOptions getLine() {
		LinePlotOptions linePlotOptions = (LinePlotOptions) getAttr(Attrs.line);
		if (linePlotOptions == null) {
			linePlotOptions = new LinePlotOptions();
			setAttr(Attrs.line, linePlotOptions);
		}
		return linePlotOptions;
	}

	/**
	 * Returns the networkgraph plot option.
	 * @since 7.2.1.0
	 */
	public NetworkGraphPlotOptions getNetworkGraph() {
		NetworkGraphPlotOptions plotOptions = (NetworkGraphPlotOptions) getAttr(Attrs.networkgraph);
		if (plotOptions == null) {
			plotOptions = new NetworkGraphPlotOptions();
			setAttr(Attrs.networkgraph, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the organization plot option
	 * @since 7.2.1.0
	 */
	public OrganizationPlotOptions getOrganization() {
		OrganizationPlotOptions plotOptions = (OrganizationPlotOptions) getAttr(Attrs.organization);
		if (plotOptions == null) {
			plotOptions = new OrganizationPlotOptions();
			setAttr(Attrs.organization, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the packed bubble plot option
	 * @since 7.2.1.0
	 */
	public PackedBubblePlotOptions getPackedBubble() {
		PackedBubblePlotOptions plotOptions = (PackedBubblePlotOptions) getAttr(Attrs.packedbubble);
		if (plotOptions == null) {
			plotOptions = new PackedBubblePlotOptions();
			setAttr(Attrs.packedbubble, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the pareto plot option
	 * @since 7.2.1.0
	 */
	public ParetoPlotOptions getPareto() {
		ParetoPlotOptions plotOptions = (ParetoPlotOptions) getAttr(Attrs.pareto);
		if (plotOptions == null) {
			plotOptions = new ParetoPlotOptions();
			setAttr(Attrs.pareto, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the pie plot option
	 */
	public PiePlotOptions getPie() {
		PiePlotOptions piePlotOptions = (PiePlotOptions) getAttr(Attrs.pie);
		if (piePlotOptions == null) {
			piePlotOptions = new PiePlotOptions();
			setAttr(Attrs.pie, piePlotOptions);
		}
		return piePlotOptions;
	}

	/**
	 * Returns the polygon plot option
	 * @since 7.2.1.0
	 */
	public PolygonPlotOptions getPolygon() {
		PolygonPlotOptions plotOptions = (PolygonPlotOptions) getAttr(Attrs.polygon);
		if (plotOptions == null) {
			plotOptions = new PolygonPlotOptions();
			setAttr(Attrs.polygon, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the pyramid plot option
	 * @since 7.2.1.0
	 */
	public PyramidPlotOptions getPyramid() {
		PyramidPlotOptions plotOptions = (PyramidPlotOptions) getAttr(Attrs.pyramid);
		if (plotOptions == null) {
			plotOptions = new PyramidPlotOptions();
			setAttr(Attrs.pyramid, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the pyramid 3D plot option
	 * @since 7.2.1.0
	 */
	public Pyramid3DPlotOptions getPyramid3D() {
		Pyramid3DPlotOptions plotOptions = (Pyramid3DPlotOptions) getAttr(Attrs.pyramid3d);
		if (plotOptions == null) {
			plotOptions = new Pyramid3DPlotOptions();
			setAttr(Attrs.pyramid3d, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the sankey plot option
	 * @since 7.2.1.0
	 */
	public SankeyPlotOptions getSankey() {
		SankeyPlotOptions plotOptions = (SankeyPlotOptions) getAttr(Attrs.sankey);
		if (plotOptions == null) {
			plotOptions = new SankeyPlotOptions();
			setAttr(Attrs.sankey, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the scatter plot option
	 */
	public ScatterPlotOptions getScatter() {
		ScatterPlotOptions scatterPlotOptions = (ScatterPlotOptions) getAttr(Attrs.scatter);
		if (scatterPlotOptions == null) {
			scatterPlotOptions = new ScatterPlotOptions();
			setAttr(Attrs.scatter, scatterPlotOptions);
		}
		return scatterPlotOptions;
	}

	/**
	 * Returns the scatter 3D plot option
	 * @since 7.2.1.0
	 */
	public Scatter3DPlotOptions getScatter3D() {
		Scatter3DPlotOptions plotOptions = (Scatter3DPlotOptions) getAttr(Attrs.scatter3d);
		if (plotOptions == null) {
			plotOptions = new Scatter3DPlotOptions();
			setAttr(Attrs.scatter3d, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the series plot option
	 */
	public SeriesPlotOptions getSeries() {
		SeriesPlotOptions seriesPlotOptions = (SeriesPlotOptions) getAttr(Attrs.series);
		if (seriesPlotOptions == null) {
			seriesPlotOptions = new SeriesPlotOptions();
			setAttr(Attrs.series, seriesPlotOptions);
		}
		return seriesPlotOptions;
	}
	
	/**
	 * Returns the solid gauge plot option
	 */
	public SolidGaugePlotOptions getSolidGauge() {
		SolidGaugePlotOptions solidGaugePlotOptions = (SolidGaugePlotOptions) getAttr(Attrs.solidgauge);
		if (solidGaugePlotOptions == null) {
			solidGaugePlotOptions = new SolidGaugePlotOptions();
			setAttr(Attrs.solidgauge, solidGaugePlotOptions);
		}
		return solidGaugePlotOptions;
	}

	/**
	 * Returns the spline plot option
	 */
	public SplinePlotOptions getSpline() {
		SplinePlotOptions splinePlotOptions = (SplinePlotOptions) getAttr(Attrs.spline);
		if (splinePlotOptions == null) {
			splinePlotOptions = new SplinePlotOptions();
			setAttr(Attrs.spline, splinePlotOptions);
		}
		return splinePlotOptions;
	}

	/**
	 * Returns the streamgraph plot option
	 * @since 7.2.1.0
	 */
	public StreamGraphPlotOptions getStreamGraph() {
		StreamGraphPlotOptions plotOptions = (StreamGraphPlotOptions) getAttr(Attrs.streamgraph);
		if (plotOptions == null) {
			plotOptions = new StreamGraphPlotOptions();
			setAttr(Attrs.streamgraph, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the sunburst plot option
	 * @since 7.2.1.0
	 */
	public SunburstPlotOptions getSunburst() {
		SunburstPlotOptions plotOptions = (SunburstPlotOptions) getAttr(Attrs.sunburst);
		if (plotOptions == null) {
			plotOptions = new SunburstPlotOptions();
			setAttr(Attrs.sunburst, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the tilemap plot option
	 * @since 7.2.1.0
	 */
	public TilemapPlotOptions getTilemap() {
		TilemapPlotOptions plotOptions = (TilemapPlotOptions) getAttr(Attrs.tilemap);
		if (plotOptions == null) {
			plotOptions = new TilemapPlotOptions();
			setAttr(Attrs.tilemap, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the timeline plot option
	 * @since 7.2.1.0
	 */
	public TimelinePlotOptions getTimeline() {
		TimelinePlotOptions plotOptions = (TimelinePlotOptions) getAttr(Attrs.timeline);
		if (plotOptions == null) {
			plotOptions = new TimelinePlotOptions();
			setAttr(Attrs.timeline, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the treemap plot option
	 */
	public TreemapPlotOptions getTree() {
		TreemapPlotOptions treemapPlotOptions = (TreemapPlotOptions) getAttr(Attrs.treemap);
		if (treemapPlotOptions == null) {
			treemapPlotOptions = new TreemapPlotOptions();
			setAttr(Attrs.treemap, treemapPlotOptions);
		}
		return treemapPlotOptions;
	}

	/**
	 * Returns the variable pie plot option
	 * @since 7.2.1.0
	 */
	public VariablePiePlotOptions getVariablePie() {
		VariablePiePlotOptions plotOptions = (VariablePiePlotOptions) getAttr(Attrs.variablepie);
		if (plotOptions == null) {
			plotOptions = new VariablePiePlotOptions();
			setAttr(Attrs.variablepie, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the variwide plot option
	 * @since 7.2.1.0
	 */
	public VariwidePlotOptions getVariwide() {
		VariwidePlotOptions plotOptions = (VariwidePlotOptions) getAttr(Attrs.variwide);
		if (plotOptions == null) {
			plotOptions = new VariwidePlotOptions();
			setAttr(Attrs.variwide, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the vector plot option
	 * @since 7.2.1.0
	 */
	public VectorPlotOptions getVector() {
		VectorPlotOptions plotOptions = (VectorPlotOptions) getAttr(Attrs.vector);
		if (plotOptions == null) {
			plotOptions = new VectorPlotOptions();
			setAttr(Attrs.vector, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the venn plot option
	 * @since 7.2.1.0
	 */
	public VennPlotOptions getVenn() {
		VennPlotOptions plotOptions = (VennPlotOptions) getAttr(Attrs.venn);
		if (plotOptions == null) {
			plotOptions = new VennPlotOptions();
			setAttr(Attrs.venn, plotOptions);
		}
		return plotOptions;
	}
	
	/**
	 * Returns the water fall plot option
	 */
	public WaterfallPlotOptions getWaterfall() {
		WaterfallPlotOptions waterfallPlotOptions = (WaterfallPlotOptions) getAttr(Attrs.waterfall);
		if (waterfallPlotOptions == null) {
			waterfallPlotOptions = new WaterfallPlotOptions();
			setAttr(Attrs.waterfall, waterfallPlotOptions);
		}
		return waterfallPlotOptions;
	}

	/**
	 * Returns the wind barb plot option
	 * @since 7.2.1.0
	 */
	public WindBarbPlotOptions getWindBarb() {
		WindBarbPlotOptions plotOptions = (WindBarbPlotOptions) getAttr(Attrs.windbarb);
		if (plotOptions == null) {
			plotOptions = new WindBarbPlotOptions();
			setAttr(Attrs.windbarb, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the word cloud plot option
	 * @since 7.2.1.0
	 */
	public WordCloudPlotOptions getWordCloud() {
		WordCloudPlotOptions plotOptions = (WordCloudPlotOptions) getAttr(Attrs.wordcloud);
		if (plotOptions == null) {
			plotOptions = new WordCloudPlotOptions();
			setAttr(Attrs.wordcloud, plotOptions);
		}
		return plotOptions;
	}

	/**
	 * Returns the xrange plot option
	 * @since 7.2.1.0
	 */
	public XRangePlotOptions getXRange() {
		XRangePlotOptions plotOptions = (XRangePlotOptions) getAttr(Attrs.xrange);
		if (plotOptions == null) {
			plotOptions = new XRangePlotOptions();
			setAttr(Attrs.xrange, plotOptions);
		}
		return plotOptions;
	}
}
