/* SankeyDataLabels.java

	Purpose:
		
	Description:
		
	History:
		Tue Nov 26 14:37:42 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.json.JavaScriptValue;

/**
 * An option of data labels used for sankey plot.
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class SankeyDataLabels extends DataLabels {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		nodeFormat, nodeFormatter
	}

	/**
	 * Returns the format string specifying what to show for nodes in tooltip of
	 * a diagram series, as opposed to links.
	 * <p>
	 * Default: "{point.name}&lt;br>{point.title}&lt;br>{point.description}"
	 */
	public String getNodeFormat() {
		return getAttr(Attrs.nodeFormat, "{point.name}<br>{point.title}<br>{point.description}").asString();
	}

	/**
	 * Sets the format string specifying what to show for nodes in tooltip of
	 * a diagram series, as opposed to links.
	 */
	public void setNodeFormat(String nodeFormat) {
		setAttr(Attrs.nodeFormat, nodeFormat);
	}

	/**
	 * Returns a callback for defining the format for nodes in the chart's tooltip, as opposed to links.
	 * <p>
	 * Default: null
	 */
	public JavaScriptValue getNodeFormatter() {
		return (JavaScriptValue) getAttr(Attrs.nodeFormatter);
	}

	/**
	 * Sets a callback for defining the format for nodes in the chart's tooltip, as opposed to links.
	 */
	public void setNodeFormatter(JavaScriptValue nodeFormatter) {
		setAttr(Attrs.nodeFormatter, nodeFormatter);
	}
}
