/* XRangePartialFill.java

	Purpose:
		
	Description:
		
	History:
		Mon Dec 09 16:42:03 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.Color;
import org.zkoss.chart.LinearGradient;
import org.zkoss.chart.Optionable;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.RadialGradient;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * A partial fill for each point, typically used to visualize how much of
 * a task is performed. The partial fill object can be set either on series
 * or point level.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class XRangePartialFill extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		amount, fill
	}

	public XRangePartialFill() {
	}

	/**
	 * Constructs with an amount.
	 */
	public XRangePartialFill(Number amount) {
		setAmount(amount);
	}

	/**
	 * Returns the amount of the X-range point to be filled.
	 * Values can be 0-1 and are converted to percentages in the default data label formatter.
	 * <p>
	 * Default: null
	 */
	public Number getAmount() {
		return getAttr(Attrs.amount, null).asNumber();
	}

	/**
	 * Sets the amount of the X-range point to be filled.
	 * Values can be 0-1 and are converted to percentages in the default data label formatter.
	 */
	public void setAmount(Number amount) {
		setAttr(Attrs.amount, amount);
	}

	/**
	 * Returns the fill color to be used for partial fills.
	 * <p>
	 * Default: a darker shade of the point color
	 */
	public Color getFill() {
		return (Color) getAttr(Attrs.fill);
	}

	/**
	 * Sets the fill color to be used for partial fills.
	 */
	public void setFill(Color fill) {
		setAttr(Attrs.fill, fill);
	}

	/**
	 * Sets the fill color to be used for partial fills.
	 */
	public void setFill(String fill) {
		setFill(new Color(fill));
	}

	/**
	 * Sets the fill color to be used for partial fills.
	 */
	public void setFill(LinearGradient fill) {
		setFill(new Color(fill));
	}

	/**
	 * Sets the fill color to be used for partial fills.
	 */
	public void setFill(RadialGradient fill) {
		setFill(new Color(fill));
	}
}
